﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using Telerik.Windows.Controls;
using Telerik.Windows.Controls.Data.DataFilter;
using Telerik.Windows.Data;

namespace DataFilterLimitFilters
{
    public class LimitedFilteringBehavior
    {
        private static RadDataFilter dataFilter;
        private static int counter;
        private static int counterLimit;

        public static int GetLimitedFilteringCount(DependencyObject obj)
        {
            return (int)obj.GetValue(LimitedFilteringCountProperty);
        }

        public static void SetLimitedFilteringCount(DependencyObject obj, int value)
        {
            obj.SetValue(LimitedFilteringCountProperty, value);
        }

        // Using a DependencyProperty as the backing store for LimitedFilteringCount.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty LimitedFilteringCountProperty =
            DependencyProperty.RegisterAttached("LimitedFilteringCount", typeof(int), typeof(LimitedFilteringBehavior), 
            new PropertyMetadata(OnLimitedFilteringPropertyChanged));

        public static void OnLimitedFilteringPropertyChanged(DependencyObject dependencyObject, DependencyPropertyChangedEventArgs e)
        {
            dataFilter = dependencyObject as RadDataFilter;

            counterLimit = (int)e.NewValue;

            if (dataFilter != null)
            {
                SubscribeToEvents(dataFilter);
            }
        }

        private static void SubscribeToEvents(RadDataFilter dataFilter)
        {
            dataFilter.AddHandler(RadButton.PreviewMouseLeftButtonDownEvent, new MouseButtonEventHandler(HandleMouse));
        }


        private static void HandleMouse(object sender, MouseButtonEventArgs e)
        {
            var source = e.OriginalSource as UIElement;

            if (source == null)
            {
                return;
            }

            var button = source.ParentOfType<RadButton>();

            if (button != null && button.Name == "PART_AddFilterButton")
            {
                counter++;
                if (counter >= counterLimit)
                {
                    e.Handled = true;
                }
            }
        }
    }
}
